/*
 * filebrowser.h
 *
 * Copyright (C) 2008 Christophe Thommeret <hftom@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef FILEBROWSER_H
#define FILEBROWSER_H

#include <QThread>
#include <QDir>

#include "osdanim.h"
#include "osdlist.h"
#include "osdthumbview.h"
#include "videowidget.h"



class BrowseThread : public QThread
{
	Q_OBJECT
public:
	BrowseThread() {
		fileFilters<<"*.m2t"<<"*.M2T"<<"*.ts"<<"*.TS"<<"*.avi"<<"*.AVI"<<"*.divx"<<"*.DIVX"<<"*.mkv"<<"*.MKV";
		fileFilters<<"*.vob"<<"*.VOB"<<"*.mpg"<<"*.MPG"<<"*.mpeg"<<"*.MPEG"<<"*.wmv"<<"*.WMV";
		fileFilters<<"*.3gp"<<"*.3GP"<<"*.mov"<<"*.MOV"<<"*.mp4"<<"*.MP4"<<"*.rm"<<"*.RM";
	}
	void browse( QDir *d, QStringList *l, QStringList *f, QStringList *t ) {
		dirList = l;
		filesList = f;
		thumbsList = t;
		dir = d;
		start();
	}
	void setThumbDir( QString d ) {
		thumbDir.setPath( d );
	}

protected:
	void run() {
		QString s;
		*dirList = dir->entryList( QDir::Dirs, QDir::Name|QDir::IgnoreCase );
		*filesList = dir->entryList( fileFilters, QDir::Files, QDir::Name|QDir::IgnoreCase );
		thumbsList->clear();
		for ( int i=0; i<filesList->count(); ++i ) {
			s = filesList->at(i);
			if ( !QFile::exists( thumbDir.filePath(QString(dir->filePath(s).remove("/").append(".jpg"))) ) ) {
				thumbsList->append( dir->filePath(filesList->at(i)) );
			}
		}
		emit done();
	}

signals:
	void done();

private:
	QStringList *dirList, *filesList, *thumbsList;
	QStringList fileFilters;
	QDir *dir;
	QDir thumbDir;
};



class FileBrowser : public OsdAnim
{
	Q_OBJECT
public:
	FileBrowser( OsdConfig *conf, VideoWidget *parent );
	~FileBrowser();
	void resize( int w, int h );
	void updateThumb( const QString &s );

	void mouseMove( QPoint &p );
	bool mouseClicked( QMouseEvent *e );
	void mouseReleased( QMouseEvent *e );
	void wheelEvent( QWheelEvent *e );
	void paint();

private slots:
	void itemClicked( QString text );
	void thumbClicked( QString text );
	void updateList();

private:
	OsdList *list;
	OsdThumbView *thumbView;
	QStringList dirList, filesList, thumbsList;
	QDir currentDir;
	BrowseThread bthread;
	VideoWidget *vw;
	QImage defThumb;
	QString dataPath;

signals:
	void play( QString mrl );
};

#endif //FILEBROWSER_H
