/*
 * osdobject.h
 *
 * Copyright (C) 2008 Christophe Thommeret <hftom@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef OSDOBJECT_H
#define OSDOBJECT_H

#include <QObject>
#include <QPainter>
#include <QMouseEvent>

#include <KDebug>

#include "mgl.h"

#define MARGINSIZE 5
#define TEXTMARGIN 3
#define SCROLLBARSIZE 16
#define MINSCROLLBARBUTTONSIZE 10



class OsdConfig
{
public:
	void setBackgroundColor( QColor c ) { bgColor = c; }
	void setForegroundColor( QColor c ) { fgColor = c; }
	void setForegroundHighColor( QColor c ) { fgHColor = c; }
	void setButtonGrad0Color( QColor c ) { btnGrad0Color = c; }
	void setButtonGrad1Color( QColor c ) { btnGrad1Color = c; }
	void setButtonHighGrad0Color( QColor c ) { btnHGrad0Color = c; }
	void setButtonHighGrad1Color( QColor c ) { btnHGrad1Color = c; }
	void setListItemGrad0Color( QColor c ) { listGrad0Color = c; }
	void setListItemGrad1Color( QColor c ) { listGrad1Color = c; }
	void setListItemHighGrad0Color( QColor c ) { listHGrad0Color = c; }
	void setListItemHighGrad1Color( QColor c ) { listHGrad1Color = c; }
	void setScrollBarGrad0Color( QColor c ) { barGrad0Color = c; }
	void setScrollBarGrad1Color( QColor c ) { barGrad1Color = c; }
	void setScrollBarBackgroundColor( QColor c ) { barBgColor = c; }
	void setNormalFont( QFont f ) { mainFont = f; }

	const QColor& backgroundColor() { return bgColor; }
	const QColor& foregroundColor() { return fgColor; }
	const QColor& foregroundHighColor() { return fgHColor; }
	const QColor& buttonGrad0Color() { return btnGrad0Color; }
	const QColor& buttonGrad1Color() { return btnGrad1Color; }
	const QColor& buttonHighGrad0Color() { return btnHGrad0Color; }
	const QColor& buttonHighGrad1Color() { return btnHGrad1Color; }
	const QColor& listItemGrad0Color() { return listGrad0Color; }
	const QColor& listItemGrad1Color() { return listGrad1Color; }
	const QColor& listItemHighGrad0Color() { return listHGrad0Color; }
	const QColor& listItemHighGrad1Color() { return listHGrad1Color; }
	const QColor& scrollBarGrad0Color() { return barGrad0Color; }
	const QColor& scrollBarGrad1Color() { return barGrad1Color; }
	const QColor& scrollBarBackgroundColor() { return barBgColor; }
	const QFont& normalFont() { return mainFont; }

	GLFunc *func;

private:
	QColor bgColor, fgColor, fgHColor;
	QColor btnGrad0Color, btnGrad1Color, btnHGrad0Color, btnHGrad1Color;
	QColor barGrad0Color, barGrad1Color, barBgColor;
	QColor listGrad0Color, listGrad1Color, listHGrad0Color, listHGrad1Color;

	QFont mainFont;
};



class OsdObject : public QObject
{
	Q_OBJECT
public:

	OsdObject( OsdConfig *conf );
	~OsdObject();

	virtual void mouseMove( QPoint& ) {}
	virtual bool mouseClicked( QMouseEvent* ) { return false; }
	virtual void mouseReleased( QMouseEvent* ) {}
	virtual void wheelEvent( QWheelEvent* ) {}
	virtual void paint() {}

	QSize size();
	int x() { return rect.x(); }
	int y() { return rect.y(); }
	int width() { return rect.width(); }
	int height() { return rect.height(); }
	void setGeometry( const QRect &r );
	void setGeometry( int x, int y, int w, int h );
	void setSize( const QSize &s );
	const QRect& area() { return rect; }

protected:
	bool inMe( int x, int y );

	QRect rect;
	bool hasFocus;
	OsdConfig *config;

signals:
	void wantRepaint();
	void clicked();
	void clicked( QString );
};
#endif // OSDOBJECT_H
